@@ -1,43 +1,28 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2010 Christoph Cullmann <cullmann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATE_TEXTLOADER_H
 #define KATE_TEXTLOADER_H
 
-#include <QString>
-#include <QFile>
 #include <QCryptographicHash>
+#include <QFile>
 #include <QMimeDatabase>
+#include <QString>
 
 // on the fly compression
 #include <KFilterDev>
 
 namespace Kate
 {
-
 /**
  * loader block size, load 256 kb at once per default
  * if file size is smaller, fall back to file size
  * must be a multiple of 2
  */
-static const qint64 KATE_FILE_LOADER_BS  = 256 * 1024;
+static const qint64 KATE_FILE_LOADER_BS = 256 * 1024;
 
 /**
  * File Loader, will handle reading of files + detecting encoding
@@ -51,16 +36,16 @@ public:
      * @param proberType prober type
      */
     TextLoader(const QString &filename, KEncodingProber::ProberType proberType)
-        : m_codec(0)
-        , m_eof(false)  // default to not eof
-        , m_lastWasEndOfLine(true)  // at start of file, we had a virtual newline
-        , m_lastWasR(false)  // we have not found a \r as last char
+        : m_codec(nullptr)
+        , m_eof(false)             // default to not eof
+        , m_lastWasEndOfLine(true) // at start of file, we had a virtual newline
+        , m_lastWasR(false)        // we have not found a \r as last char
         , m_position(0)
         , m_lastLineStart(0)
-        , m_eol(TextBuffer::eolUnknown)  // no eol type detected atm
+        , m_eol(TextBuffer::eolUnknown) // no eol type detected atm
         , m_buffer(KATE_FILE_LOADER_BS, 0)
         , m_digest(QCryptographicHash::Sha1)
-        , m_converterState(0)
+        , m_converterState(nullptr)
         , m_bomFound(false)
         , m_firstRead(true)
         , m_proberType(proberType)
@@ -87,7 +72,7 @@ public:
 
     /**
      * open file with given codec
-     * @param codec codec to use, if 0, will do some auto-dectect or fallback
+     * @param codec codec to use, if 0, will do some auto-detect or fallback
      * @return success
      */
     bool open(QTextCodec *codec)
@@ -101,15 +86,15 @@ public:
         m_eol = TextBuffer::eolUnknown;
         m_text.clear();
         delete m_converterState;
-        m_converterState = new QTextCodec::ConverterState(QTextCodec::ConvertInvalidToNull);
+        m_converterState = new QTextCodec::ConverterState(QTextCodec::DefaultConversion);
         m_bomFound = false;
         m_firstRead = true;
-        
+
         // init the hash with the git header
         const QString header = QStringLiteral("blob %1").arg(m_fileSize);
         m_digest.reset();
         m_digest.addData(header.toLatin1() + '\0');
-        
+
         // if already opened, close the file...
         if (m_file->isOpen()) {
             m_file->close();
@@ -156,8 +141,8 @@ public:
     }
 
     /**
-     * internal unicode data array
-     * @return internal unicode data
+     * internal Unicode data array
+     * @return internal Unicode data
      */
     const QChar *unicode() const
     {
@@ -174,8 +159,8 @@ public:
     }
 
     /**
-     * read a line, return length + offset in unicode data
-     * @param offset offset into internal unicode data for read line
+     * read a line, return length + offset in Unicode data
+     * @param offset offset into internal Unicode data for read line
      * @param length length of read line
      * @return true if no encoding errors occurred
      */
@@ -204,7 +189,7 @@ public:
                 if (!m_eof) {
                     // kill the old lines...
                     m_text.remove(0, m_lastLineStart);
-                    
+
                     // try to read new data
                     const int c = m_file->read(m_buffer.data(), m_buffer.size());
 
@@ -212,13 +197,13 @@ public:
                     if (c > 0) {
                         // update hash sum
                         m_digest.addData(m_buffer.data(), c);
-                    
-                        // detect byte order marks & codec for byte order markers on first read
+
+                        // detect byte order marks & codec for byte order marks on first read
                         int bomBytes = 0;
                         if (m_firstRead) {
                             // use first 16 bytes max to allow BOM detection of codec
                             QByteArray bom(m_buffer.data(), qMin(16, c));
-                            QTextCodec *codecForByteOrderMark = QTextCodec::codecForUtfText(bom, 0);
+                            QTextCodec *codecForByteOrderMark = QTextCodec::codecForUtfText(bom, nullptr);
 
                             // if codec != null, we found a BOM!
                             if (codecForByteOrderMark) {
@@ -248,16 +233,16 @@ public:
                                     m_codec = codecForByteOrderMark;
                                 } else {
                                     /**
-                                     * no unicode BOM found, trigger prober
+                                     * no Unicode BOM found, trigger prober
                                      */
-                                    
+
                                     /**
                                      * first: try to get HTML header encoding
                                      */
-                                    if (QTextCodec *codecForHtml = QTextCodec::codecForHtml (m_buffer, 0)) {
+                                    if (QTextCodec *codecForHtml = QTextCodec::codecForHtml(m_buffer, nullptr)) {
                                         m_codec = codecForHtml;
                                     }
-                                    
+
                                     /**
                                      * else: use KEncodingProber
                                      */
@@ -281,17 +266,11 @@ public:
                             m_firstRead = false;
                         }
 
+                        // detect broken encoding, we did before use QTextCodec::ConvertInvalidToNull and check for 0 chars
+                        // this lead to issues with files containing 0 chars, therefore use the invalidChars field of the state
                         Q_ASSERT(m_codec);
                         QString unicode = m_codec->toUnicode(m_buffer.constData() + bomBytes, c - bomBytes, m_converterState);
-
-                        // detect broken encoding
-                        for (int i = 0; i < unicode.size(); ++i) {
-                            if (unicode[i] == 0) {
-                                encodingError = true;
-                                break;
-                            }
-                        }
-
+                        encodingError = encodingError || m_converterState->invalidChars;
                         m_text.append(unicode);
                     }
 
@@ -323,7 +302,8 @@ public:
                 }
             }
 
-            if (m_text.at(m_position) == lf) {
+            QChar current_char = m_text.at(m_position);
+            if (current_char == lf) {
                 m_lastWasEndOfLine = true;
 
                 if (m_lastWasR) {
@@ -345,7 +325,7 @@ public:
 
                     return !encodingError;
                 }
-            } else if (m_text.at(m_position) == cr) {
+            } else if (current_char == cr) {
                 m_lastWasEndOfLine = true;
                 m_lastWasR = true;
 
@@ -362,7 +342,7 @@ public:
                 }
 
                 return !encodingError;
-            } else if (m_text.at(m_position) == QChar::LineSeparator) {
+            } else if (current_char == QChar::LineSeparator) {
                 m_lastWasEndOfLine = true;
 
                 // line data
