@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2001-2010 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2009 Erlend Hamberg <ehamberg@gmail.com>
 
-    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2009 Erlend Hamberg <ehamberg@gmail.com>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kateglobal.h"
@@ -28,17 +14,15 @@
 #include "katecmd.h"
 #include "katecmds.h"
 #include "kateconfig.h"
-#include "katedefaultcolors.h"
 #include "katedocument.h"
 #include "katehighlightingcmds.h"
 #include "katekeywordcompletion.h"
 #include "katemodemanager.h"
 #include "katepartdebug.h"
 #include "katerenderer.h"
-#include "kateschema.h"
-#include "kateschemaconfig.h"
 #include "katescriptmanager.h"
 #include "katesedcmd.h"
+#include "katethemeconfig.h"
 #include "katevariableexpansionmanager.h"
 #include "kateview.h"
 #include "katewordcompletion.h"
@@ -49,10 +33,10 @@
 
 #include <KAboutData>
 #include <KConfigGroup>
+#include <KDirWatch>
 #include <KLocalizedString>
 #include <KPageDialog>
 #include <KPageWidgetModel>
-#include <KDirWatch>
 
 #include <QApplication>
 #include <QBoxLayout>
@@ -85,13 +69,12 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
                   QStringLiteral(KTEXTEDITOR_VERSION_STRING),
                   i18n("Embeddable editor component"),
                   KAboutLicense::LGPL_V2,
-                  i18n("(c) 2000-2019 The Kate Authors"),
+                  i18n("(c) 2000-2020 The Kate Authors"),
                   QString(),
                   QStringLiteral("https://kate-editor.org"))
     , m_dummyApplication(nullptr)
     , m_application(&m_dummyApplication)
     , m_dummyMainWindow(nullptr)
-    , m_defaultColors(new KateDefaultColors())
     , m_searchHistoryModel(nullptr)
     , m_replaceHistoryModel(nullptr)
 {
@@ -103,9 +86,7 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     git_libgit2_init();
 #endif
 
-    /**
-     * register some datatypes
-     */
+    // register some datatypes
     qRegisterMetaType<KTextEditor::Cursor>("KTextEditor::Cursor");
     qRegisterMetaType<KTextEditor::Document *>("KTextEditor::Document*");
     qRegisterMetaType<KTextEditor::View *>("KTextEditor::View*");
@@ -159,9 +140,7 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
 
     m_aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
-    /**
-     * set proper Kate icon for our about dialog
-     */
+    // set proper Kate icon for our about dialog
     m_aboutData.setProgramLogo(QIcon(QStringLiteral(":/ktexteditor/kate.svg")));
 
     //
@@ -189,11 +168,6 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     //
     m_modeManager = new KateModeManager();
 
-    //
-    // schema man
-    //
-    m_schemaManager = new KateSchemaManager();
-
     //
     // input mode factories
     //
@@ -247,7 +221,6 @@ KTextEditor::EditorPrivate::~EditorPrivate()
     delete m_rendererConfig;
 
     delete m_modeManager;
-    delete m_schemaManager;
 
     delete m_dirWatch;
 
@@ -344,7 +317,7 @@ KTextEditor::ConfigPage *KTextEditor::EditorPrivate::configPage(int number, QWid
         return new KateViewDefaultsConfig(parent);
 
     case 1:
-        return new KateSchemaConfigPage(parent);
+        return new KateThemeConfigPage(parent);
 
     case 2:
         return new KateEditConfigTab(parent);
@@ -364,46 +337,32 @@ KTextEditor::ConfigPage *KTextEditor::EditorPrivate::configPage(int number, QWid
  */
 static void cleanupGlobal()
 {
-    /**
-     * delete if there
-     */
+    // delete if there
     delete KTextEditor::EditorPrivate::self();
 }
 
 KTextEditor::EditorPrivate *KTextEditor::EditorPrivate::self()
 {
-    /**
-     * remember the static instance in a QPointer
-     */
+    // remember the static instance in a QPointer
     static bool inited = false;
     static QPointer<KTextEditor::EditorPrivate> staticInstance;
 
-    /**
-     * just return it, if already inited
-     */
+    // just return it, if already inited
     if (inited) {
         return staticInstance.data();
     }
 
-    /**
-     * start init process
-     */
+    // start init process
     inited = true;
 
-    /**
-     * now create the object and store it
-     */
+    // now create the object and store it
     new KTextEditor::EditorPrivate(staticInstance);
 
-    /**
-     * register cleanup
-     * let use be deleted during QCoreApplication shutdown
-     */
+    // register cleanup
+    // let use be deleted during QCoreApplication shutdown
     qAddPostRoutine(cleanupGlobal);
 
-    /**
-     * return instance
-     */
+    // return instance
     return staticInstance.data();
 }
 
@@ -453,10 +412,8 @@ KateVariableExpansionManager *KTextEditor::EditorPrivate::variableExpansionManag
 
 void KTextEditor::EditorPrivate::updateColorPalette()
 {
-    // update default color cache
-    m_defaultColors.reset(new KateDefaultColors());
-
     // reload the global schema (triggers reload for every view as well)
+    // might trigger selection of better matching theme for new palette
     m_rendererConfig->reloadSchema();
 
     // force full update of all view caches and colors
@@ -465,31 +422,23 @@ void KTextEditor::EditorPrivate::updateColorPalette()
 
 void KTextEditor::EditorPrivate::copyToClipboard(const QString &text)
 {
-    /**
-     * empty => nop
-     */
+    // empty => nop
     if (text.isEmpty()) {
         return;
     }
 
-    /**
-     * move to clipboard
-     */
+    // move to clipboard
     QApplication::clipboard()->setText(text, QClipboard::Clipboard);
 
-    /**
-     * LRU, kill potential duplicated, move new entry to top
-     * cut after 10 entries
-     */
+    // LRU, kill potential duplicated, move new entry to top
+    // cut after 10 entries
     m_clipboardHistory.removeOne(text);
     m_clipboardHistory.prepend(text);
     if (m_clipboardHistory.size() > 10) {
         m_clipboardHistory.removeLast();
     }
 
-    /**
-     * notify about change
-     */
+    // notify about change
     emit clipboardHistoryChanged();
 }
 
